@@ -16,10 +16,23 @@ sub send_request (&@) {
     no warnings 'redefine';
     local *Furl::HTTP::request = sub {
         shift;
-        my $ret = $mock->(@_);
-        my $http_status = delete $ret->{http_status} // 200;
-        my $json = encode_json $ret;
+        my @ret = $mock->(@_);
+
+        my ($http_status, $headers, $body);
+        if (@ret == 1) {
+            $body = $ret[0];
+        } elsif (@ret == 2) {
+            ($http_status, $body) = @ret;
+        } elsif (@ret == 3) {
+            ($http_status, $headers, $body) = @ret;
+        }
+
+        $http_status //= delete $body->{http_status} // 200;
+        $headers //= [];
+
+        my $json = encode_json $body;
         return ('0', $http_status, 'OK', [
+            @$headers,
             'X-Line-Request-Id' => 'dummy_id',
             'Content-Type'      => 'application/json; charset=UTF-8',
             'Content-Length'    => length($json),
